@@ -330,7 +330,8 @@ class Qctrl:
         Use another thread to check qctrl version.
         """
         for package in PackageRegistry:
-            if not package.is_lazy() or package.is_installed():
+            if package.is_installed():
+                _ = package.import_pkg()
                 Thread(target=package.check_latest_version, daemon=True).start()
 
 
