@@ -228,9 +228,8 @@ def check_client_version(func):
 # a namedtuple to define basic information of a package
 # name : the official name of the package
 # url : the URL for hosting the package on PyPI
-# is_lazy : a boolean flag. If true, meaning the package should be only
 # imported when locally available
-_PackageInfo = namedtuple("_PackageInfo", ["name", "url", "is_lazy"])
+_PackageInfo = namedtuple("_PackageInfo", ["name", "url"])
 _QCTRL_URL = "https://pypi.org/pypi/qctrl/json"
 _TOOLKIT_URL = "https://pypi.org/pypi/qctrl-toolkit/json"
 
@@ -240,8 +239,8 @@ class PackageRegistry(Enum):
     Lists Q-CTRL related packages.
     """
 
-    QCTRL = _PackageInfo("Q-CTRL", _QCTRL_URL, False)
-    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", _TOOLKIT_URL, True)
+    QCTRL = _PackageInfo("Q-CTRL", _QCTRL_URL)
+    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", _TOOLKIT_URL)
 
     def check_latest_version(self):
         """
@@ -261,10 +260,6 @@ class PackageRegistry(Enum):
         """checks whether a package is locally available."""
         return importlib.util.find_spec(self.get_package_name()) is not None
 
-    def is_lazy(self) -> bool:
-        """Checks if a package should be imported lazily."""
-        return self.value.is_lazy
-
     def import_pkg(self):
         """Import the package if it's not already in the sys modules."""
         pkg_name = self.get_package_name()
@@ -274,8 +269,8 @@ class PackageRegistry(Enum):
             if spec is None:
                 raise ImportError(f"{self.value.name} not found")
             module = importlib.util.module_from_spec(spec)
-            sys.modules[pkg_name] = module
             spec.loader.exec_module(module)
+            sys.modules[pkg_name] = module
             return sys.modules[pkg_name]
         return pkg
 
